pydecorate
==========

.. image:: https://github.com/pytroll/pydecorate/workflows/CI/badge.svg?branch=main
    :target: https://github.com/pytroll/pydecorate/actions?query=workflow%3A%22CI%22

.. image:: https://coveralls.io/repos/github/pytroll/pydecorate/badge.svg?branch=main
    :target: https://coveralls.io/github/pytroll/pydecorate?branch=main

Pydecorate is a package for decorating PIL images with logos, texts, and color
scales.

Originally created by Hrobjartur Thorsteinsson
November 2013, from Norrkoping, Sweden
